@@ -1,7 +1,7 @@
 # coding: utf-8
 
 from vxci.get_addons import get_module_list, get_modules2test
-from vxbase import types, net
+from vxbase import types, net, fromenv
 import distutils.spawn
 from docker import errors, from_env
 import json
@@ -180,11 +180,6 @@ def slugify(s):
     return re.sub(r'[-]+', '-', slug)
 
 
-def is_github():
-    v = environ.get('GITHUB_ACTION', False)
-    return type(v) is not bool and v is False
-
-
 def map_github_action(config):
     config['ci_commit_ref_name'] = config.get('github_ref_name')
     config['ci_job_id'] = config.get('github_run_id')
@@ -208,7 +203,8 @@ def get_config(**kwargs):
     for key in kwargs:
         res.update({key.lower(): get_value(key, **kwargs)})
 
-    if is_github():
+    if fromenv.is_github():
+        _logger.debug('Inside github action')
         map_github_action(res)
     res.update({'private_deploy_key': res.get('private_deploy_key', False)})
     img_name = generate_image_name('{0}_{1}'.format(
